@@ -1,14 +1,14 @@
 
-/*
- *  $Id: c52675c053ab8d4afc6af169d3eca0ad63f2fcae $
+/**
+ * @file defLex.c
  *
- *  Time-stamp:        "2010-02-24 08:43:07 bkorb"
+ *  Time-stamp:        "2011-06-03 12:20:36 bkorb"
  *
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,7 +23,7 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-tSCC zErrMsg[] = "%s Error:  %s in %s on line %d\n";
+static char const zErrMsg[] = "%s Error:  %s in %s on line %d\n";
 
 /*
  *  This keyword table must match those found in agParse.y.
@@ -34,19 +34,19 @@ tSCC zErrMsg[] = "%s Error:  %s in %s on line %d\n";
   _KW_( AUTOGEN )                               \
   _KW_( DEFINITIONS )
 
-#define _KW_(w) tSCC z ## w [] = #w;
+#define _KW_(w) static char const z ## w [] = #w;
 KEYWORD_TABLE
 #undef _KW_
 
 #define _KW_(w) z ## w,
-tSCC*  apzKeywords[] = { KEYWORD_TABLE };
+static char const*  apzKeywords[] = { KEYWORD_TABLE };
 #undef _KW_
 
 #define _KW_(w) DP_EV_ ## w,
 te_dp_event aKeywordTkn[] = { KEYWORD_TABLE };
 #undef _KW_
 
-#define KEYWORD_CT  (sizeof( apzKeywords ) / sizeof( apzKeywords[0] ))
+#define KEYWORD_CT  (sizeof(apzKeywords) / sizeof(apzKeywords[0]))
 
 #define ERROR  (-1)
 #define FINISH (-1)
@@ -55,24 +55,177 @@ te_dp_event aKeywordTkn[] = { KEYWORD_TABLE };
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
-loadScheme( void );
+pop_context(void);
 
 static void
-alist_to_autogen_def( void );
+trim_whitespace(void);
+
+static void
+lex_escaped_char(void);
+
+static tSuccess
+lex_backquote(void);
+
+static tSuccess
+lex_comment(void);
+
+static tSuccess
+lex_here_string(void);
+
+static void
+loadScheme(void);
+
+static void
+alist_to_autogen_def(void);
 
 static char*
-assembleName( char* pzScan, te_dp_event* pRetVal );
+assembleName(char * pzScan, te_dp_event * pRetVal);
 
 static char*
-assembleHereString( char* pzScan );
+assembleHereString(char* pzScan);
 /* = = = END-STATIC-FORWARD = = = */
 
+/**
+ *  Pop off an include context and resume from the including file.
+ */
+static void
+pop_context(void)
+{
+    tScanCtx* pCX = pCurCtx;
+    pCurCtx   = pCurCtx->pCtx;
+    pCX->pCtx = pDoneCtx;
+    pDoneCtx  = pCX;
+}
+
+static void
+trim_whitespace(void)
+{
+    char* pz = pCurCtx->pzScan;
+    if (*pz == NL)
+        pCurCtx->lineNo++;
+    *(pz++) = NUL;
+
+    /*
+     *  This ensures that any names found previously
+     *  are NUL terminated.
+     */
+    while (IS_WHITESPACE_CHAR(*pz)) {
+        if (*pz == NL)
+            pCurCtx->lineNo++;
+        pz++;
+    }
+    pCurCtx->pzScan = pz;
+}
+
+static void
+lex_escaped_char(void)
+{
+    char* pz = strchr(pCurCtx->pzScan, ';');
+
+    for (;;) {
+        if (pz == NULL) {
+            pz = pCurCtx->pzScan + strlen(pCurCtx->pzScan);
+            break;
+        }
+        if (IS_WHITESPACE_CHAR(pz[1])) {
+            *pz = NUL;
+            pz[1] = ';';
+            break;
+        }
+        pz = strchr(pz+1, ';');
+    }
+
+    lastToken = DP_EV_STRING;
+    pz_token = pz;
+}
+
+static tSuccess
+lex_backquote(void)
+{
+    int line_no = pCurCtx->lineNo;
+    char* pz = ao_string_cook(pCurCtx->pzScan, &line_no);
+
+    if (pz == NULL)
+        return FAILURE;
+
+    pz_token = pCurCtx->pzScan;
+
+    pCurCtx->pzScan = pz;
+
+    lastToken = DP_EV_STRING;
+    pz = shell_cmd((char const*)pz_token);
+    pCurCtx->lineNo = line_no;
+
+    if (pz == NULL)
+        return PROBLEM;
+    TAGMEM(pz, "shell definition string");
+    pz_token = pz;
+    manageAllocatedData(pz);
+    return SUCCESS;
+}
+
+static tSuccess
+lex_comment(void)
+{
+    /*
+     *  Allow for a comment, C or C++ style
+     */
+    switch (pCurCtx->pzScan[1]) {
+    case '*':
+    {
+        char* pz = strstr(pCurCtx->pzScan+2, "*/");
+        if (pz != NULL) {
+            char* p = pCurCtx->pzScan+1;
+            for (;;) {
+                p = strchr(p+1, NL);
+                if ((p == NULL) || (p > pz))
+                    break;
+                pCurCtx->lineNo++;
+            }
+            pCurCtx->pzScan = pz+2;
+            return SUCCESS;
+        }
+        break;
+    }
+    case '/':
+    {
+        char* pz = strchr(pCurCtx->pzScan+2, NL);
+        if (pz != NULL) {
+            pCurCtx->pzScan = pz+1;
+            pCurCtx->lineNo++;
+            return SUCCESS;
+        }
+        break;
+    }
+    }
+
+    return FAILURE;
+}
+
+static tSuccess
+lex_here_string(void)
+{
+    char* pz;
+    if (pCurCtx->pzScan[1] != '<')
+        return FAILURE;
+
+    pz = assembleHereString(pCurCtx->pzScan + 2);
+    if (pz == NULL) {
+        lastToken = DP_EV_INVALID;
+        return PROBLEM;
+    }
+
+    lastToken = DP_EV_HERE_STRING;
+    pCurCtx->pzScan = pz;
+    return SUCCESS;
+}
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *   LEXICAL SCANNER
  */
 LOCAL te_dp_event
-yylex( void )
+yylex(void)
 {
     lastToken = DP_EV_INVALID;
 
@@ -82,23 +235,8 @@ scanAgain:
      *  We branch here after skipping over a comment
      *  or processing a directive (which may change our context).
      */
-    if (IS_WHITESPACE_CHAR( *pCurCtx->pzScan )) {
-        char* pz = pCurCtx->pzScan;
-        if (*pz == '\n')
-            pCurCtx->lineNo++;
-        *(pz++) = NUL;
-
-        /*
-         *  This ensures that any names found previously
-         *  are NUL terminated.
-         */
-        while (IS_WHITESPACE_CHAR(*pz)) {
-            if (*pz == '\n')
-                pCurCtx->lineNo++;
-            pz++;
-        }
-        pCurCtx->pzScan = pz;
-    }
+    if (IS_WHITESPACE_CHAR(*pCurCtx->pzScan))
+        trim_whitespace();
 
     switch (*pCurCtx->pzScan) {
     case NUL:
@@ -109,22 +247,13 @@ scanAgain:
         if (pCurCtx->pCtx == NULL)
             goto lex_done;
 
-        /*
-         *  Pop off an include context and resume
-         *  from the including file.
-         */
-        {
-            tScanCtx* pCX = pCurCtx;
-            pCurCtx = pCurCtx->pCtx;
-            pCX->pCtx = pDoneCtx;
-            pDoneCtx  = pCX;
-        }
+        pop_context();
         goto scanAgain;
 
     case '#':
     {
-        extern char* processDirective( char* );
-        char* pz = processDirective( pCurCtx->pzScan+1 );
+        extern char * processDirective(char*);
+        char * pz = processDirective(pCurCtx->pzScan+1);
         /*
          *  Ensure that the compiler doesn't try to save a copy of
          *  "pCurCtx" in a register.  It must be reloaded from memory.
@@ -133,18 +262,18 @@ scanAgain:
         goto scanAgain;
     }
 
-    case '{': SET_LIT_TKN( O_BRACE );   break;
-    case '=': SET_LIT_TKN( EQ );        break;
-    case '}': SET_LIT_TKN( C_BRACE );   break;
-    case '[': SET_LIT_TKN( OPEN_BKT );  break;
-    case ']': SET_LIT_TKN( CLOSE_BKT ); break;
-    case ';': SET_LIT_TKN( SEMI );      break;
-    case ',': SET_LIT_TKN( COMMA );     break;
+    case '{': SET_LIT_TKN(O_BRACE);   break;
+    case '=': SET_LIT_TKN(EQ);        break;
+    case '}': SET_LIT_TKN(C_BRACE);   break;
+    case '[': SET_LIT_TKN(OPEN_BKT);  break;
+    case ']': SET_LIT_TKN(CLOSE_BKT); break;
+    case ';': SET_LIT_TKN(SEMI);      break;
+    case ',': SET_LIT_TKN(COMMA);     break;
 
     case '\'':
     case '"':
     {
-        char* pz = ao_string_cook( pCurCtx->pzScan, &(pCurCtx->lineNo));
+        char* pz = ao_string_cook(pCurCtx->pzScan, &(pCurCtx->lineNo));
         if (pz == NULL)
             goto NUL_error;
 
@@ -156,113 +285,43 @@ scanAgain:
     }
 
     case '<':
-    {
-        char* pz;
-        if (pCurCtx->pzScan[1] != '<')
-            goto BrokenToken;
-
-        pz = assembleHereString(pCurCtx->pzScan + 2);
-        if (pz == NULL) {
-            lastToken = DP_EV_INVALID;
-            return DP_EV_INVALID;
+        switch (lex_here_string()) {
+        case SUCCESS: break;
+        case FAILURE: goto BrokenToken;
+        case PROBLEM: return DP_EV_INVALID;
         }
-
-        lastToken = DP_EV_HERE_STRING;
-        pCurCtx->pzScan = pz;
         break;
-    }
 
     case '(':
         loadScheme();
         break;
 
     case '\\':
-        if (strncmp( pCurCtx->pzScan+1, "'(", (size_t)2) == 0) {
+        if (strncmp(pCurCtx->pzScan+1, "'(", (size_t)2) == 0) {
             alist_to_autogen_def();
             goto scanAgain;
-
-        } else {
-            char* pz = strchr( pCurCtx->pzScan, ';' );
-
-            for (;;) {
-                if (pz == NULL) {
-                    pz = pCurCtx->pzScan + strlen( pCurCtx->pzScan );
-                    break;
-                }
-                if (IS_WHITESPACE_CHAR( pz[1] )) {
-                    *pz = NUL;
-                    pz[1] = ';';
-                    break;
-                }
-                pz = strchr( pz+1, ';' );
-            }
-
-            lastToken = DP_EV_STRING;
-            pz_token = pz;
-            break;
         }
+        lex_escaped_char();
+        break;
 
     case '`':
-    {
-        int line_no = pCurCtx->lineNo;
-        char* pz = ao_string_cook( pCurCtx->pzScan, &line_no);
-
-        if (pz == NULL)
-            goto NUL_error;
-
-        pz_token = pCurCtx->pzScan;
-
-        pCurCtx->pzScan = pz;
-
-        lastToken = DP_EV_STRING;
-        pz = runShell( (char const*)pz_token );
-        pCurCtx->lineNo = line_no;
-
-        if (pz == NULL)
-            goto scanAgain;
-        TAGMEM( pz, "shell definition string" );
-        pz_token = pz;
-        manageAllocatedData( pz );
+        switch (lex_backquote()) {
+        case FAILURE: goto NUL_error;
+        case PROBLEM: goto scanAgain;
+        case SUCCESS: break;
+        }
         break;
-    }
 
     case '/':
-        /*
-         *  Allow for a comment, C or C++ style
-         */
-        switch (pCurCtx->pzScan[1]) {
-        case '*':
-        {
-            char* pz = strstr( pCurCtx->pzScan+2, "*/" );
-            if (pz != NULL) {
-                char* p = pCurCtx->pzScan+1;
-                for (;;) {
-                    p = strchr( p+1, '\n' );
-                    if ((p == NULL) || (p > pz))
-                        break;
-                    pCurCtx->lineNo++;
-                }
-                pCurCtx->pzScan = pz+2;
-                goto scanAgain;
-            }
-            break;
-        }
-        case '/':
-        {
-            char* pz = strchr( pCurCtx->pzScan+2, '\n' );
-            if (pz != NULL) {
-                pCurCtx->pzScan = pz+1;
-                pCurCtx->lineNo++;
-                goto scanAgain;
-            }
-            break;
-        }
+        switch (lex_comment()) {
+        case SUCCESS: goto scanAgain;
+        default: break;
         }
         /* FALLTHROUGH */ /* to Invalid input char */
 
     default:
     BrokenToken:
-        pCurCtx->pzScan = assembleName( pCurCtx->pzScan, &lastToken );
+        pCurCtx->pzScan = assembleName(pCurCtx->pzScan, &lastToken);
         break;
     }   /* switch (*pCurCtx->pzScan) */
 
@@ -270,8 +329,8 @@ scanAgain:
 
 NUL_error:
 
-    AG_ABEND( aprf( zErrMsg, pzProg, "unterminated quote in definition",
-                    pCurCtx->pzCtxFname, pCurCtx->lineNo ));
+    AG_ABEND(aprf(zErrMsg, pzProg, "unterminated quote in definition",
+                  pCurCtx->pzCtxFname, pCurCtx->lineNo));
     return DP_EV_INVALID;
 
 lex_done:
@@ -292,14 +351,21 @@ lex_done:
 
 
 LOCAL void
-yyerror( char* s )
+yyerror(char* s)
 {
-    tSCC zErrTkn[] = "%s:  ``%s''\n";
-    tSCC zDf[] = "`%s'\n";
+    static char const yyerr_fmt[] =
+        "%s:  in %s on line %d\n"
+        "\ttoken in error:  %s\n"
+        "\t[[...<error-text>]] %s\n\n"
+        "Likely causes:  a mismatched quote, a value that needs "
+        "quoting,\n\t\tor a missing semi-colon\n";
+
+    static char const zErrTkn[] = "%s:  ``%s''\n";
+    static char const zDf[] = "`%s'\n";
 
     char* pz;
 
-    if (strlen( pCurCtx->pzScan ) > 64 )
+    if (strlen(pCurCtx->pzScan) > 64 )
         pCurCtx->pzScan[64] = NUL;
 
     switch (lastToken) {
@@ -307,30 +373,25 @@ yyerror( char* s )
     case DP_EV_OTHER_NAME:
     case DP_EV_STRING:
     case DP_EV_NUMBER:
-        if (strlen( pz_token ) > 64 )
+        if (strlen(pz_token) > 64 )
             pz_token[64] = NUL;
 
-        pz = aprf( zErrTkn, DP_EVT_NAME( lastToken ), pz_token );
+        pz = aprf(zErrTkn, DP_EVT_NAME(lastToken), pz_token);
         break;
 
     default:
-        pz = aprf( zDf, DP_EVT_NAME( lastToken ));
+        pz = aprf(zDf, DP_EVT_NAME(lastToken));
     }
-    AG_ABEND( aprf( "%s:  in %s on line %d\n"
-                    "\ttoken in error:  %s\n"
-                    "\t[[...<error-text>]] %s\n\n"
-                    "Likely causes:  a mismatched quote, a value that needs "
-                    "quoting,\n\t\tor a missing semi-colon\n",
-                    s, pCurCtx->pzCtxFname, pCurCtx->lineNo, pz,
-                    pCurCtx->pzScan ));
+    AG_ABEND(aprf(yyerr_fmt, s, pCurCtx->pzCtxFname, pCurCtx->lineNo, pz,
+                  pCurCtx->pzScan));
 }
 
 
 static void
-loadScheme( void )
+loadScheme(void)
 {
     char*    pzText    = pCurCtx->pzScan;
-    char*    pzEnd     = (char*)skipScheme( pzText, pzText + strlen( pzText ));
+    char*    pzEnd     = (char*)skipScheme(pzText, pzText + strlen(pzText));
     char     endCh     = *pzEnd;
     int      schemeLen = (pzEnd - pzText);
     int      next_ln;
@@ -355,21 +416,21 @@ loadScheme( void )
     *pzEnd = endCh;
 
     pCurCtx->pzScan = pzEnd;
-    pzEnd = (char*)resolveSCM( res ); /* ignore const-ness */
+    pzEnd = (char*)resolveSCM(res); /* ignore const-ness */
     pCurCtx->lineNo = next_ln;
 
-    if (strlen( pzEnd ) >= schemeLen) {
-        AGDUPSTR( pzEnd, pzEnd, "SCM Result" );
+    if (strlen(pzEnd) >= schemeLen) {
+        AGDUPSTR(pzEnd, pzEnd, "SCM Result");
 
         pz_token = pzEnd;
-        manageAllocatedData( pz_token );
+        manageAllocatedData(pz_token);
     }
 
     else {
         /*
          *  We know the result is smaller than the source.  Copy in place.
          */
-        strcpy( pzText, pzEnd );
+        strcpy(pzText, pzEnd);
         pz_token = pzText;
     }
 
@@ -381,13 +442,13 @@ loadScheme( void )
  *  into AutoGen definitions.
  */
 static void
-alist_to_autogen_def( void )
+alist_to_autogen_def(void)
 {
-    tSCC   zSchemeText[] = "Scheme Computed Definitions";
-    tSCC   zWrap[] = "(alist->autogen-def %s)";
+    static char const zSchemeText[] = "Scheme Computed Definitions";
+    static char const zWrap[] = "(alist->autogen-def %s)";
 
     char*  pzText  = ++(pCurCtx->pzScan);
-    char*  pzEnd   = (char*)skipScheme( pzText, pzText + strlen( pzText ));
+    char*  pzEnd   = (char*)skipScheme(pzText, pzText + strlen(pzText));
 
     SCM    res;
     size_t res_len;
@@ -399,7 +460,7 @@ alist_to_autogen_def( void )
     {
         char endCh = *pzEnd;
         *pzEnd = NUL;
-        pzText = aprf( zWrap, pzText );
+        pzText = aprf(zWrap, pzText);
         *pzEnd = endCh;
     }
 
@@ -413,12 +474,13 @@ alist_to_autogen_def( void )
     /*
      *  The result *must* be a string, or we choke.
      */
-    if (! AG_SCM_STRING_P( res )) {
-        tSCC zEr[] = "Scheme definition expression does not yield string:\n";
-        AG_ABEND( zEr );
+    if (! AG_SCM_STRING_P(res)) {
+        static char const zEr[] =
+            "Scheme definition expression does not yield string:\n";
+        AG_ABEND(zEr);
     }
 
-    res_len   = AG_SCM_STRLEN( res );
+    res_len   = AG_SCM_STRLEN(res);
     procState = PROC_STATE_LOAD_DEFS;
     pCurCtx->pzScan = pzEnd;
     AGFREE(pzText);
@@ -427,18 +489,18 @@ alist_to_autogen_def( void )
      *  Now, push the resulting string onto the input stack
      *  and link the new scan data into the context stack
      */
-    pCtx = (tScanCtx*)AGALOC( sizeof(tScanCtx) + 4 + res_len, "lex scan ctx" );
+    pCtx = (tScanCtx*)AGALOC(sizeof(tScanCtx) + 4 + res_len, "lex scan ctx");
     pCtx->pCtx  = pCurCtx;
     pCurCtx     = pCtx;
 
     /*
      *  Set up the rest of the context structure
      */
-    AGDUPSTR( pCtx->pzCtxFname, zSchemeText, "scheme text" );
+    AGDUPSTR(pCtx->pzCtxFname, zSchemeText, "scheme text");
     pCtx->pzScan = \
     pCtx->pzData = (char*)(pCtx+1);
     pCtx->lineNo = 0;
-    memcpy( (void*)(pCtx->pzScan), (void*)AG_SCM_CHARS( res ), res_len );
+    memcpy((void*)(pCtx->pzScan), (void*)AG_SCM_CHARS(res), res_len);
     pCtx->pzScan[ res_len ] = NUL;
 
     /*
@@ -456,25 +518,25 @@ alist_to_autogen_def( void )
  *  Figure out which.
  */
 static char*
-assembleName( char* pzScan, te_dp_event* pRetVal )
+assembleName(char * pzScan, te_dp_event * pRetVal)
 {
     /*
      *  Check for a number.
      *  Scan it in and advance "pzScan".
      */
-    if (  IS_DEC_DIGIT_CHAR( *pzScan )
+    if (  IS_DEC_DIGIT_CHAR(*pzScan)
        || (  (*pzScan == '-')
-          && IS_DEC_DIGIT_CHAR( pzScan[1] )
+          && IS_DEC_DIGIT_CHAR(pzScan[1])
        )  )  {
         pz_token = pzScan;
-        (void)strtol( pzScan, &pzScan, 0 );
+        (void)strtol(pzScan, &pzScan, 0);
         *pRetVal = DP_EV_NUMBER;
         return pzScan;
     }
 
     if (! IS_UNQUOTABLE_CHAR(*pzScan))
-        AG_ABEND( aprf("%s Error: Invalid input char '%c' in %s on line %d\n",
-                       pzProg, *pzScan, pCurCtx->pzCtxFname, pCurCtx->lineNo));
+        AG_ABEND(aprf("%s Error: Invalid input char '%c' in %s on line %d\n",
+                      pzProg, *pzScan, pCurCtx->pzCtxFname, pCurCtx->lineNo));
 
     {
         unsigned char* pz = (unsigned char*)pzScan;
@@ -505,7 +567,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
         *pzScan = NUL;         /* NUL terminate the name           */
 
         do  {
-            if (streqvcmp( apzKeywords[ kw_ix ], (char*)pz_token ) == 0) {
+            if (streqvcmp(apzKeywords[ kw_ix ], (char*)pz_token) == 0) {
                 /*
                  *  Return the keyword token code instead of DP_EV_NAME
                  */
@@ -527,7 +589,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
  *  Find the end of it and compress any escape sequences.
  */
 static char*
-assembleHereString( char* pzScan )
+assembleHereString(char* pzScan)
 {
     static char const endless[] = "Unterminated HereString";
     ag_bool  trimTabs = AG_FALSE;
@@ -547,10 +609,10 @@ assembleHereString( char* pzScan )
     /*
      *  Skip white space up to the marker or EOL
      */
-    while (IS_WHITESPACE_CHAR( *pzScan )) {
-        if (*pzScan++ == '\n')
-            AG_ABEND( aprf( zErrMsg, pzProg, "HereString missing the mark",
-                            pCurCtx->pzCtxFname, pCurCtx->lineNo ));
+    while (IS_WHITESPACE_CHAR(*pzScan)) {
+        if (*pzScan++ == NL)
+            AG_ABEND(aprf(zErrMsg, pzProg, "HereString missing the mark",
+                          pCurCtx->pzCtxFname, pCurCtx->lineNo));
     }
 
     /*
@@ -558,17 +620,17 @@ assembleHereString( char* pzScan )
      */
     {
         char* pz = zMark;
-        while (IS_VARIABLE_NAME_CHAR( *pzScan )) {
+        while (IS_VARIABLE_NAME_CHAR(*pzScan)) {
             if (++markLen >= sizeof(zMark))
-                AG_ABEND( aprf( zErrMsg, pzProg, "HereString mark "
-                                STR( MAX_HEREMARK_LEN ) " or more chars",
-                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
+                AG_ABEND(aprf(zErrMsg, pzProg, "HereString mark "
+                              STR(MAX_HEREMARK_LEN) " or more chars",
+                              pCurCtx->pzCtxFname, pCurCtx->lineNo));
 
             *(pz++) = *(pzScan++);
         }
         if (markLen == 0)
-            AG_ABEND( aprf( zErrMsg, pzProg, "HereString missing the mark",
-                            pCurCtx->pzCtxFname, pCurCtx->lineNo ));
+            AG_ABEND(aprf(zErrMsg, pzProg, "HereString missing the mark",
+                          pCurCtx->pzCtxFname, pCurCtx->lineNo));
         *pz = NUL;
     }
 
@@ -578,10 +640,10 @@ assembleHereString( char* pzScan )
     /*
      *  Skip forward to the EOL after the marker.
      */
-    pzScan = strchr( pzScan, '\n' );
+    pzScan = strchr(pzScan, NL);
     if (pzScan == NULL)
-        AG_ABEND( aprf( zErrMsg, pzProg, endless, pCurCtx->pzCtxFname,
-                        pCurCtx->lineNo ));
+        AG_ABEND(aprf(zErrMsg, pzProg, endless, pCurCtx->pzCtxFname,
+                      pCurCtx->lineNo));
 
     /*
      *  And skip the first new line + conditionally skip tabs
@@ -590,30 +652,30 @@ assembleHereString( char* pzScan )
     pzScan++;
 
     if (trimTabs)
-        while (*pzScan == '\t')  ++pzScan;
+        while (*pzScan == TAB)  ++pzScan;
 
     /*
      *  FOR as long as the text does not match the mark
      *       OR it matches but is a substring
      *  DO copy characters
      */
-    while (  (strncmp( pzScan, zMark, markLen ) != 0)
-          || IS_VARIABLE_NAME_CHAR( pzScan[ markLen ]) )  {
+    while (  (strncmp(pzScan, zMark, markLen) != 0)
+          || IS_VARIABLE_NAME_CHAR(pzScan[markLen]) )  {
 
         for (;;) {
             switch (*(pzDest++) = *(pzScan++)) {
-            case '\n':
+            case NL:
                 pCurCtx->lineNo++;
                 goto lineDone;
 
             case NUL:
-                AG_ABEND( aprf( zErrMsg, pzProg, endless, pCurCtx->pzCtxFname,
-                                here_string_line_no));
+                AG_ABEND(aprf(zErrMsg, pzProg, endless, pCurCtx->pzCtxFname,
+                              here_string_line_no));
             }
         } lineDone:;
 
         if (trimTabs)
-            while (*pzScan == '\t')  ++pzScan;
+            while (*pzScan == TAB)  ++pzScan;
     } /* while strncmp ... */
 
     /*
