@@ -1,11 +1,11 @@
 
 /**
- * \file expState.c
+ * @file expState.c
  *
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  *
- *  Time-stamp:        "2011-02-17 15:33:17 bkorb"
+ *  Time-stamp:        "2011-12-15 12:21:13 bkorb"
  *
  *  This file is part of AutoGen.
  *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
@@ -306,42 +306,9 @@ ag_scm_version_compare(SCM op, SCM v1, SCM v2)
     ver_type_t val2 = str2int_ver(ag_scm2zchars(v2, zVer));
     v1 = SCM_FROM(val1);
     v2 = SCM_FROM(val2);
-    return scm_apply(op, v1, scm_cons(v2, scm_listofnull));
+    return scm_apply(op, v1, scm_cons(v2, AG_SCM_LISTOFNULL()));
 }
 
-
-/*=gfunc chdir
- *
- * what:   Change current directory
- *
- * exparg: dir, new directory name
- *
- * doc:  Sets the current directory for AutoGen.  Shell commands will run
- *       from this directory as well.  This is a wrapper around the Guile
- *       native function.  It returns its directory name argument and
- *       fails the program on failure.
-=*/
-SCM
-ag_scm_chdir(SCM dir)
-{
-    static char const zChdirDir[] = "chdir directory";
-
-    scm_chdir(dir);
-
-    /*
-     *  We're still here, so we have a valid argument.
-     */
-    if (pCurDir != NULL)
-        free(pCurDir);
-    {
-        char const * pz = ag_scm2zchars(dir, zChdirDir);
-        pCurDir = malloc(AG_SCM_STRLEN(dir) + 1);
-        strcpy((char*)pCurDir, pz);
-    }
-    return dir;
-}
-
-
 /*=gfunc count
  *
  * what:   definition count
@@ -518,17 +485,8 @@ ag_scm_get(SCM agName, SCM altVal)
 SCM
 ag_scm_get_c_name(SCM agName)
 {
-    tDefEntry*  pE;
-    ag_bool     x;
-
-    if (! AG_SCM_STRING_P(agName))
-         pE = NULL;
-    else pE = findDefEntry(ag_scm2zchars(agName, "ag value"), &x);
-
-    if ((pE == NULL) || (pE->valType != VALTYP_TEXT))
-        return AG_SCM_STR02SCM(zNil);
-
-    return ag_scm_string_to_c_name_x(AG_SCM_STR02SCM(pE->val.pzText));
+    return ag_scm_string_to_c_name_x(
+        ag_scm_get(agName, SCM_UNDEFINED));
 }
 
 
