@@ -1,10 +1,10 @@
 
 /**
- * \file funcDef.c
+ * @file funcDef.c
  *
  *  This module implements the DEFINE text function.
  *
- *  Time-stamp:        "2011-04-21 16:51:41 bkorb"
+ *  Time-stamp:        "2011-10-09 17:33:18 bkorb"
  *
  *  This file is part of AutoGen.
  *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
@@ -51,7 +51,7 @@ static void
 fill_in_values(tDefList * pDL, char * pzScan, tTemplate* pT, tMacro* pMac);
 
 static void
-prep_invoke_args(tMacro* pMac);
+prep_invoke_args(tMacro * pMac);
 
 static void
 build_defs(int defCt, tDefList* pList);
@@ -338,10 +338,10 @@ parseMacroArgs(tTemplate* pT, tMacro* pMac)
 }
 
 static void
-prep_invoke_args(tMacro* pMac)
+prep_invoke_args(tMacro * pMac)
 {
-    char*  pzText;
-    tTemplate* pT = pCurTemplate;
+    char * pzText;
+    tTemplate * pT = pCurTemplate;
 
     if (pMac->ozText == 0)
         AG_ABEND_IN(pT, pMac, "The INVOKE macro requires a name");
@@ -512,7 +512,7 @@ build_defs(int defCt, tDefList* pList)
                 fprintf(pfTrace, "shell eval for arg %d:\n\t`%s'\n",
                         pCurMacro->sibIndex - defCt, pList->pzExpr+1);
             }
-            pList->de.val.pzText = runShell(pList->pzExpr+1);
+            pList->de.val.pzText = shell_cmd(pList->pzExpr+1);
             break;
         }
     } while (pList++, --defCt > 0);
@@ -682,8 +682,8 @@ mUnload_Define(tMacro* pMac)
  *  the first time the macro is processed and evaluated again every
  *  time the macro is evaluated.
 =*/
-tMacro*
-mFunc_Invoke(tTemplate* pT, tMacro* pMac)
+tMacro *
+mFunc_Invoke(tTemplate * pT, tMacro * pMac)
 {
     char* pzText;
     SCM   macName;
@@ -735,28 +735,28 @@ mFunc_Invoke(tTemplate* pT, tMacro* pMac)
     return mFunc_Define(pT, pMac);
 }
 
-
-/* Load Debug
- *
- *  what:   Loads the debug function so you can set breakpoints
- *          at load time, too :-)
+/**
+ * Loads the debug function for load time breakpoints.
+ * @param pT     containing template
+ * @param pMac   the debug macro data
+ * @param ppzSan pointer to scanning pointer
+ * @returns      the next open macro slot
  */
-tMacro*
-mLoad_Debug(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
+tMacro *
+mLoad_Debug(tTemplate * pT, tMacro * pMac, char const ** ppzScan)
 {
     if (OPT_VALUE_TRACE >= TRACE_DEBUG_MESSAGE)
         return mLoad_Unknown(pT, pMac, ppzScan);
     return mLoad_Comment(pT, pMac, ppzScan);
 }
 
-
-tMacro*
-mLoad_Define(tTemplate* pT, tMacro* pMac, char const ** ppzScan)
+tMacro *
+mLoad_Define(tTemplate * pT, tMacro * pMac, char const ** ppzScan)
 {
     static char const zNameNeeded[] = "DEFINE requires a name";
 
-    char*        pzCopy;             /* next text dest   */
-    tTemplate*   pNewT;
+    char *       pzCopy;             /* next text dest   */
+    tTemplate *  pNewT;
 
     /*
      *  Save the global macro loading mode
