@@ -2,8 +2,7 @@
 
 ## texi2mdoc.sh -- script to convert texi-isms to mdoc-isms
 ##
-## Time-stamp:      "2011-02-03 16:16:33 bkorb"
-## Author:          Jim Van Zandt <jrv@vanzandt.mv.com>
+## Time-stamp:      "2011-03-30 15:13:15 bkorb"
 ##
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
@@ -43,23 +42,6 @@ esac
 parent_pid=$$
 prog=`basename $0 .sh`
 
-fixfont='
-s;@code{\([^}]*\)};\\fB\1\\fP;g
-s;@var{\([^}]*\)};\\fB\1\\fP;g
-s;@samp{\([^}]*\)};\\fB\1\\fP;g
-s;@i{\([^}]*\)};\\fI\1\\fP;g
-s;@file{\([^}]*\)};\\fI\1\\fP;g
-s;@emph{\([^}]*\)};\\fI\1\\fP;g
-s;@strong{\([^}]*\)};\\fB\1\\fP;g
-s/@\([{@}]\)/\1/g
-s,^[@$]\*$,.br,
-s/\*\([a-zA-Z0-9:~=_ -]*\)\*/\\fB\1\\fP/g
-s/``\([a-zA-Z0-9:~+=_ -]*\)'\'\''/\\(lq\1\\(rq/g
-s/ -/ \\-/g
-/^\.[A-Z][a-z] /s@ \\-@ -@g'"
-s/^'/\\'/"
-readonly fixfont
-
 die() {
     echo "$prog error:  $*" >&2
     kill -TERM $parent_pid
@@ -70,7 +52,7 @@ die() {
 }
 
 do_example() {
-    echo '.Bd -offset indent'
+    echo '.Bd -literal -offset indent'
     res=0
 
     while :
@@ -151,6 +133,9 @@ do_item() {
 
 do_line() {
     case "${line}" in
+    '@*' ) echo .br ;;
+    ''   ) echo .sp ;;
+    '@'[{}]* ) echo "${line}" | sed 's/@\([{}]\)/\1/g' ;;
     '@'* )
         typ=`echo "$line" | egrep '@[a-z]*\{'`
         test ${#typ} -gt 0 && echo "$line" && return 0
@@ -165,9 +150,32 @@ do_line() {
     return 0
 }
 
-(
+fixfont='
+s;@code{\([^}]*\)};\\fB\1\\fP;g
+s;@var{\([^}]*\)};\\fB\1\\fP;g
+s;@samp{\([^}]*\)};\\fB\1\\fP;g
+s;@i{\([^}]*\)};\\fI\1\\fP;g
+s;@file{\([^}]*\)};\\fI\1\\fP;g
+s;@emph{\([^}]*\)};\\fI\1\\fP;g
+s;@strong{\([^}]*\)};\\fB\1\\fP;g
+s;@pxref{\([^}]*\)};see: \1;g
+s;@xref{\([^}]*\)};see: \1;g
+s/@\([{@}]\)/\1/g
+s,^[@$]\*$,.br,
+s/\*\([a-zA-Z0-9:~=_ -]*\)\*/\\fB\1\\fP/g
+s/``\([a-zA-Z0-9:~+=_ -]*\)'\'\''/\\(lq\1\\(rq/g
+s/\([^\\]\)-/\1\\-/g
+s/\([^\\]\)-/\1\\-/g
+/^\.\(Bl\|Bd\|in\) /s/ \\-/ -/g'"
+s/^'/\\'/
+/^$/d"
+readonly fixfont
+
+{
     while IFS='' read -r line
     do
         do_line
     done
-) | sed "${fixfont}"
+} | sed "${fixfont}"
+
+exit 0
