@@ -2,13 +2,13 @@
 /*
  *  \file columns.c
  *
- *  Time-stamp:        "2010-12-09 10:44:57 bkorb"
+ *  Time-stamp:        "2011-03-04 10:17:17 bkorb"
  *
- *  Columns Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ *  Columns Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *  Columns is free software.
  *  This file is part of AutoGen.
  *
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2011 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -152,36 +152,33 @@ malloc_or_die(size_t sz)
 static char const *
 construct_first_pfx(char const * f_indent)
 {
-    char const pad_fmt[] = "%%-%ds";
+    static char const pad_fmt[] = "%%-%ds";
     // 24 > log10(0xFFFFFFFFFFFFFFFFULL)
     char pfx_buf[24 + sizeof(pad_fmt)];
-    size_t firstSize;
-    size_t len = indentSize + 3;
+    size_t firstSize = pad_indentation(f_indent, &pzFirstPfx);
+    size_t len;
     char * res;
 
-    /*
-     *  The first line has a special indentation/prefix.
-     *  Compute it, but do not let it be larger than
-     *  the indentation value.
-     */
-    firstSize = pad_indentation(f_indent, &pzFirstPfx);
-
-    sprintf(pfx_buf, pad_fmt, (int)indentSize);
-
     /*
      *  If this first line exceeds the indentation size, then we
      *  need to append a newline and any indentation.
      */
-    if (firstSize > indentSize)
-        len += HAVE_OPT(LINE_SEPARATION) ? strlen( OPT_ARG(LINE_SEPARATION)) : 0
-            + indentSize;
+    if (firstSize > indentSize) {
+        size_t sep_len = HAVE_OPT(LINE_SEPARATION)
+            ? strlen( OPT_ARG(LINE_SEPARATION)) : 0;
+        len = firstSize + sep_len + indentSize + 3;
+        sprintf(pfx_buf, pad_fmt, (int)firstSize);
+    } else {
+        len = indentSize + 3;
+        sprintf(pfx_buf, pad_fmt, (int)indentSize);
+    }
 
-    res = malloc_or_die(indentSize + 1);
-    snprintf(res, indentSize + 1, pfx_buf, pzFirstPfx);
+    res = malloc_or_die(len);
+    snprintf(res, len, pfx_buf, pzFirstPfx);
     pzFirstPfx = res;
 
     if (firstSize > indentSize) {
-        char * p = res + strlen(res);
+        char * p = res + firstSize;
 
         if (HAVE_OPT( LINE_SEPARATION )) {
             len = strlen(OPT_ARG(LINE_SEPARATION));
@@ -199,24 +196,28 @@ static uint32_t
 pad_indentation(char const * pzIndentArg, char const ** pfx)
 {
     char * pz;
-    unsigned int colCt = (unsigned int)strtoul(pzIndentArg, &pz, 0);
+    unsigned int cct;
+
+    errno = 0;
+    cct = (unsigned int)strtoul(pzIndentArg, &pz, 0);
 
     /*
      *  IF the indent argument is a number
      */
-    if ((*pz == NUL) && (colCt > 0) && (colCt < OPT_VALUE_WIDTH)) {
+    if ((*pz == NUL) && (errno == 0) && (cct < OPT_VALUE_WIDTH)) {        
         char * p;
 
         /*
          *  Allocate a string to hold the line prefix
          */
-        *pfx = p = malloc_or_die( (size_t)colCt + 1 );
+        *pfx = p = malloc_or_die( (size_t)cct + 1 );
 
         /*
          *  Set it to a NUL terminated string of spaces
          */
-        memset(p, ' ', (size_t)colCt);
-        p[colCt] = NUL;
+        if (cct > 0)
+            memset(p, ' ', (size_t)cct);
+        p[cct] = NUL;
 
     } else {
         /*
@@ -226,7 +227,7 @@ pad_indentation(char const * pzIndentArg, char const ** pfx)
          */
         char const * p = pzIndentArg;
         *pfx = pzIndentArg;
-        colCt     =  0;
+        cct     =  0;
 
         for (;;) {
             /*
@@ -237,18 +238,18 @@ pad_indentation(char const * pzIndentArg, char const ** pfx)
                 goto colsCounted;
 
             case '\t':
-                colCt += OPT_VALUE_TAB_WIDTH;
-                colCt -= (colCt % OPT_VALUE_TAB_WIDTH);
+                cct += OPT_VALUE_TAB_WIDTH;
+                cct -= (cct % OPT_VALUE_TAB_WIDTH);
                 break;
 
             case '\n':
             case '\f':
             case '\r':
-                colCt = 0;
+                cct = 0;
                 break;
 
             default:
-                colCt++;
+                cct++;
                 break;
 
             case '\a':
@@ -257,7 +258,7 @@ pad_indentation(char const * pzIndentArg, char const ** pfx)
         } colsCounted:;
     }
 
-    return colCt;
+    return cct;
 }
 
 
